# gtdb-lib

[![PyPI](https://img.shields.io/pypi/v/gtdblib.svg)](https://pypi.python.org/pypi/gtdblib)

An abstraction of objects, files, and third-party tools used by the GTDB. Not intended for public use.

The library is under active development and the API will change frequently, it is strongly recommended to 
specify a specific version when using it.


## Installation

Python >= 3.6 is required.

```bash
python -m pip install gtdb
```


## Contributing

### Commit guidelines
This project uses [Semantic Versioning](http://semver.org/) and [Conventional Commits](https://conventionalcommits.org/)
to automatically generate release notes using [Semantic Release](https://semantic-release.gitbook.io/semantic-release/).
If you are using PyCharm, then [Git Commit Template](https://plugins.jetbrains.com/plugin/9861-git-commit-template) will be useful.
